package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.FriendLink;

/**
 * 友链导航Service接口
 * 
 * @author boman
 * @date 2021-12-29
 */
public interface IFriendLinkService 
{
    /**
     * 查询友链导航
     * 
     * @param linkId 友链导航主键
     * @return 友链导航
     */
    public FriendLink selectFriendLinkByLinkId(Long linkId);

    /**
     * 查询友链导航列表
     * 
     * @param friendLink 友链导航
     * @return 友链导航集合
     */
    public List<FriendLink> selectFriendLinkList(FriendLink friendLink);

    /**
     * 新增友链导航
     * 
     * @param friendLink 友链导航
     * @return 结果
     */
    public int insertFriendLink(FriendLink friendLink);

    /**
     * 修改友链导航
     * 
     * @param friendLink 友链导航
     * @return 结果
     */
    public int updateFriendLink(FriendLink friendLink);

    /**
     * 批量删除友链导航
     * 
     * @param linkIds 需要删除的友链导航主键集合
     * @return 结果
     */
    public int deleteFriendLinkByLinkIds(Long[] linkIds);

    /**
     * 删除友链导航信息
     * 
     * @param linkId 友链导航主键
     * @return 结果
     */
    public int deleteFriendLinkByLinkId(Long linkId);
}
